// Copyright (c) 2021 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include <stdint.h>
#include <malloc.h>
#include "../display/tileset.h"

typedef uint8_t tileflag_t;
typedef uint16_t tileref_t;

typedef struct {
  tileflag_t flags;
} tile_t;

typedef struct {
  tile_t *tiles;
  tileset_t *tileset;
} tilemap_t;

#define TILE_NULL (tileref_t)0
#define TILE_FLAG_DYNAMIC (tileflag_t)1
#define TILE_FLAG_3D (tileflag_t)2
#define TILE_FLAG_SOLID (tileflag_t)4

/**
 * Creates a tilemap from a tileset.
 * 
 * @param tileset Tileset to create from.
 * @returns The tilemap.
 */
tilemap_t * tileMapCreate(tileset_t *tileset);

/**
 * Destroys a previously created tilemap.
 * 
 * @param tilemap Tilemap to dispose.
 */
void tileMapDispose(tilemap_t *tilemap);